package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.AlarmLog;
import com.ruoyi.base.service.IAlarmLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 安防告警日志Controller
 *
 * @author ruoyi
 * @date 2026-05-20
 */
@RestController
@RequestMapping("/base/alarmLog")
public class AlarmLogController extends BaseController
{
    @Autowired
    private IAlarmLogService alarmLogService;

    /**
     * 查询安防告警日志列表
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(AlarmLog alarmLog)
    {
        startPage();
        List<AlarmLog> list = alarmLogService.selectAlarmLogList(alarmLog);
        return getDataTable(list);
    }

    /**
     * 导出安防告警日志列表
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:export')")
    @Log(title = "安防告警日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AlarmLog alarmLog)
    {
        List<AlarmLog> list = alarmLogService.selectAlarmLogList(alarmLog);
        ExcelUtil<AlarmLog> util = new ExcelUtil<AlarmLog>(AlarmLog.class);
        util.exportExcel(response, list, "安防告警日志数据");
    }

    /**
     * 获取安防告警日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(alarmLogService.selectAlarmLogById(id));
    }

    /**
     * 新增安防告警日志
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:add')")
    @Log(title = "安防告警日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AlarmLog alarmLog)
    {
        return toAjax(alarmLogService.insertAlarmLog(alarmLog));
    }

    /**
     * 修改安防告警日志
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:edit')")
    @Log(title = "安防告警日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AlarmLog alarmLog)
    {
        return toAjax(alarmLogService.updateAlarmLog(alarmLog));
    }

    /**
     * 删除安防告警日志
     */
    @PreAuthorize("@ss.hasPermi('base:alarmLog:remove')")
    @Log(title = "安防告警日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(alarmLogService.deleteAlarmLogByIds(ids));
    }
}
